package com.wood.consumerhystrix.controller;

import com.netflix.hystrix.contrib.javanica.annotation.HystrixCommand;
import com.wood.consumerhystrix.remote.EurekaServiceFeign;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * HelloController
 * </p>
 *
 * @author wood
 * @Date 2019/1/28
 */
@RestController
public class HelloController {

    @Autowired
    private EurekaServiceFeign eurekaServiceFeign;

    /**
     * hystrix配合feign使用
     * 当feign连接出现故障，就不会再去请求了，直接进入fallback
     * tip:默认开启了两个provider-user服务，每次访问时交替出现，feign自带负载均衡的功能
     * 如果满足不了需求可以加上Ribbon来实现专业的负载均衡
     * @RibbonClient(name="provider-user", configuration=RibbonRuleConfig.class)
     * */
    @GetMapping("/hello/{name}")
    @ResponseBody
    @HystrixCommand(fallbackMethod = "helloFallback")
    public String hello(@PathVariable String name){
        return eurekaServiceFeign.hello(name);
    }

    // 对应上面的方法，参数必须一致当访问失败时，hystrix直接回调用此方法
    public String helloFallback(String name) {
        return name + "\nhystrix配合feign使用，当feign连接出现故障，就不会再去请求了，直接进入fallback";
    }
}
